{#
  Copyright (C) 2020 CERN.
  Copyright (C) 2020 Northwestern University.
  Copyright (C) 2021 TU Wien.
  Copyright (C) 2022 New York University.

  Invenio RDM Records is free software; you can redistribute it and/or modify
  it under the terms of the MIT License; see LICENSE file for more details.
#}

{%  if stats %}
<section id="metrics" aria-label="{{ _('Metrics') }}" class="ui segment rdm-sidebar">
  {%- include "invenio_app_rdm/records/details/stats.html" %}
</section>
{% endif %}

