{#
  Copyright (C) 2020 CERN.
  Copyright (C) 2020 Northwestern University.
  Copyright (C) 2021 TU Wien.
  Copyright (C) 2022 New York University.

  Invenio RDM Records is free software; you can redistribute it and/or modify
  it under the terms of the MIT License; see LICENSE file for more details.
-#}

<section id="record-versions" aria-label="{{ _('Record versions') }}" class="ui segment rdm-sidebar">
  <h2 class="ui small header">{{ _('Versions')}}</h2>
  <div class="versions">
    <div id="recordVersions" data-record='{{ record | tojson }}' data-preview='{{ is_preview | tojson }}'></div>
  </div>
</section>
